@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_FIXEDEFFECTS_WORKING_GLOBAL_BLOCK_H
+#define GLMMGS_FIXEDEFFECTS_WORKING_GLOBAL_BLOCK_H
 
 #include "../../../Standard.h"
 #include "../../../Variables/IVariable.h"
@@ -36,3 +37,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
