@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_FIXEDEFFECTS_WORKING_GLOBAL_COEFFICIENTS_H
+#define GLMMGS_FIXEDEFFECTS_WORKING_GLOBAL_COEFFICIENTS_H
 
 #include "../../../Standard.h"
 #include "../../../Estimate.h"
@@ -49,3 +50,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
