@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_FIXEDEFFECTS_WORKING_IBLOCK_H
+#define GLMMGS_FIXEDEFFECTS_WORKING_IBLOCK_H
 
 #include "../../Standard.h"
 #include "../../Estimate.h"
@@ -28,3 +29,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
