@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_OFFSETS_WEAKVECTOROFFSET_H
+#define GLMMGS_OFFSETS_WEAKVECTOROFFSET_H
 
 #include "../Standard.h"
 #include "IOffset.h"
@@ -41,6 +42,8 @@ namespace GlmmGS
 			_ASSERT_ARGUMENT(eta.Size() == this->values.Size());
 			for (int i = 0; i < this->values.Size(); ++i)
 				eta(i) = this->values(i);
-		};
+		}
 	}
 }
+
+#endif
