@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_GLOBAL_COVARIANCEMODEL_ICOVARIANCEMODEL_H
+#define GLMMGS_RANDOMEFFECTS_GLOBAL_COVARIANCEMODEL_ICOVARIANCEMODEL_H
 
 #include "../../../Standard.h"
 #include "../../Working/Global/CovarianceModels/ICovarianceModel.h"
@@ -26,3 +27,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
