@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_STRATIFIED_BLOCK_H
+#define GLMMGS_RANDOMEFFECTS_STRATIFIED_BLOCK_H
 
 #include "../../Standard.h"
 #include "../../Variables/IVariable.h"
@@ -34,3 +35,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
