@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_STRATIFIED_COVARIANCE_MODELS_SPARSEPRECISIONMODEL_H
+#define GLMMGS_RANDOMEFFECTS_STRATIFIED_COVARIANCE_MODELS_SPARSEPRECISIONMODEL_H
 
 #include "../../../Standard.h"
 #include "../../Working/Stratified/CovarianceModels/ICovarianceModel.h"
@@ -32,3 +33,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
