@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_WORKING_IBLOCK_H
+#define GLMMGS_RANDOMEFFECTS_WORKING_IBLOCK_H
 
 #include "../../Standard.h"
 #include "../../Estimate.h"
@@ -29,3 +30,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
