@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_WORKING_STRATIFIED_IBLOCK_H
+#define GLMMGS_RANDOMEFFECTS_WORKING_STRATIFIED_IBLOCK_H
 
 #include "../../../Standard.h"
 #include "../../../Variables/IVariable.h"
@@ -40,3 +41,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
