@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGS_RANDOMEFFECTS_WORKING_STRATIFIED_COVARIANCEMODELS_ICOVARIANCEMODEL_H
+#define GLMMGS_RANDOMEFFECTS_WORKING_STRATIFIED_COVARIANCEMODELS_ICOVARIANCEMODEL_H
 
 #include "../../../../Standard.h"
 #include "../../../../Estimate.h"
@@ -46,3 +47,5 @@ namespace GlmmGS
 		}
 	}
 }
+
+#endif
