@@ -1,4 +1,6 @@
-#pragma once
+#ifndef GLMMGSAPI_RANDOMEFFECTS_RANDOMEFFECTS_GLOBAL_BLOCKSECTION_H
+#define GLMMGSAPI_RANDOMEFFECTS_RANDOMEFFECTS_GLOBAL_BLOCKSECTION_H
+
 
 #include "../../Standard.h"
 #include "../../Section.h"
@@ -33,3 +35,5 @@ namespace GlmmGSAPI
 		}
 	}
 }
+
+#endif
