@@ -1,4 +1,5 @@
-#pragma once
+#ifndef GLMMGSAPI_RANDOMEFFECTS_RANDOMEFFECTS_STRATIFIED_BLOCKSECTION_H
+#define GLMMGSAPI_RANDOMEFFECTS_RANDOMEFFECTS_STRATIFIED_BLOCKSECTION_H
 
 #include "../../Standard.h"
 #include "../../Section.h"
@@ -36,3 +37,5 @@ namespace GlmmGSAPI
 		}
 	}
 }
+
+#endif
