@@ -1,5 +1,8 @@
-#pragma once
+#ifndef UTILITIES_IO_IO_H
+#define UTILITIES_IO_IO_H
 
 #include "Stream.h"
 #include "BasicPrint.h"
 #include "Print.h"
+
+#endif
