@@ -1,7 +1,10 @@
-#pragma once
+#ifndef UTILITIES_LINEARALGEBRA_LINEARALGEBRA_H
+#define UTILITIES_LINEARALGEBRA_LINEARALGEBRA_H
 
 #include "VectorFunctions.h"
 #include "MatrixFunctions.h"
 #include "TriangularMatrixFunctions.h"
 #include "CholeskyDecomposition.h"
 #include "VectorialCholeskyDecomposition.h"
+
+#endif
