@@ -1,4 +1,5 @@
-#pragma once
+#ifndef UTILITIES_UTILITIES_H
+#define UTILITIES_UTILITIES_H
 
 // Weak types
 #include "WeakString.h"
@@ -25,3 +26,5 @@
 
 // Min, Max (vector version), IsSorted
 #include "VectorAlgorithms.h"
+
+#endif
